handle_refresh

Function handle_refresh 

pub async fn handle_refresh() -> Result<()>
Handle oxicode refresh — force-refresh the model catalog from models.dev.

Performs a conditional GET (ETag). The refreshed cache takes effect on the next process start (the in-memory catalog is immutable).

Uses the catalog port (FileModelCatalog) directly. The App’s catalog would be equivalent but this command runs standalone (no App).