Module enc

Module enc 

Encoder-based structs and traits

Re-exports

pub use self::write::SizeWriter;
pub use self::write::SliceWriter;
pub use self::write::Writer;
pub use self::write::VecWriter;alloc
pub use self::write::IoWriter;std
pub use self::write::StdWriter;std

Modules

write
Encoding functionality

Structs

EncoderImpl
An Encoder that writes bytes into a given writer W.

Traits

Encode
Encode trait for types that can be encoded to binary format
Encoder
Encoder trait for encoding values with configuration