Error

Enum Error 

#[non_exhaustive]
pub enum Error {
Show 16 variants UnexpectedEnd { additional: usize, }, InvalidData { message: &'static str, }, InvalidIntegerType { expected: IntegerType, found: IntegerType, }, InvalidBooleanValue(u8), InvalidCharEncoding([u8; 4]), Utf8 { inner: Utf8Error, }, LimitExceeded { limit: u64, found: u64, }, Io { kind: ErrorKind, message: String, }, Custom { message: &'static str, }, OwnedCustom { message: String, }, OutsideUsizeRange(u64), NonZeroTypeIsZero { non_zero_type: IntegerType, }, UnexpectedVariant { found: u32, type_name: &'static str, }, InvalidDuration { secs: u64, nanos: u32, }, InvalidSystemTime { duration: Duration, }, ChecksumMismatch { expected: u32, found: u32, },
}
Error type for encoding and decoding operations

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnexpectedEnd

Unexpected end of input during decoding

Fields

additional: usize

Estimate of additional bytes needed



InvalidData

Invalid data encountered during decoding

Fields

message: &'static str

Description of what went wrong



InvalidIntegerType

Invalid integer type during varint decoding

Fields

expected: IntegerType

The type that was expected

found: IntegerType

The type that was found



InvalidBooleanValue(u8)

Invalid boolean value



InvalidCharEncoding([u8; 4])

Invalid character encoding



Utf8

Available on crate feature alloc only.

UTF-8 decoding error

Fields

inner: Utf8Error

The inner UTF-8 error



LimitExceeded

Configuration limit exceeded

Fields

limit: u64

The limit that was configured

found: u64

The value that exceeded the limit



Io

Available on crate feature std only.

IO error during encoding or decoding

Fields

kind: ErrorKind

Error kind

message: String

Error message



Custom

Custom error message (static string)

Fields

message: &'static str

Error message



OwnedCustom

Available on crate feature alloc only.

Custom error message (owned string, from serde or dynamic sources)

Fields

message: String

Error message



OutsideUsizeRange(u64)

Value outside usize range (for platforms with smaller usize)



NonZeroTypeIsZero

NonZero type decoded as zero

Fields

non_zero_type: IntegerType

The NonZero type that was zero



UnexpectedVariant

Invalid enum variant

Fields

found: u32

The variant index found

type_name: &'static str

Type name for context



InvalidDuration

Available on crate feature std only.

Invalid duration (nanos >= 1_000_000_000)

Reserved: this variant is not yet constructed by the current decoding paths (which report out-of-range Duration values via Error::InvalidData instead). It is kept public and documented so that future wire-compatibility work can switch those call sites to a structured error without a breaking enum change.

Fields

secs: u64

Seconds component

nanos: u32

Nanoseconds component (should be < 1_000_000_000)



InvalidSystemTime

Available on crate feature std only.

Invalid SystemTime (before UNIX_EPOCH)

Reserved: this variant is not yet constructed by the current decoding paths (which report out-of-range SystemTime values via Error::InvalidData instead). It is kept public and documented so that future wire-compatibility work can switch those call sites to a structured error without a breaking enum change.

Fields

duration: Duration

Duration before UNIX_EPOCH



ChecksumMismatch

Available on crate feature checksum only.

Checksum mismatch during data verification

Fields

expected: u32

Expected CRC32 checksum

found: u32

Found CRC32 checksum