encoded_size_with_config

Function encoded_size_with_config 

pub fn encoded_size_with_config<E: Encode, C: Config>(
    value: &E,
    config: C,
) -> Result<usize>
Calculate the encoded size of a value with a custom configuration.

This uses a SizeWriter internally to count bytes without actually encoding to a buffer.