pub async fn run_print_mode(app: &App, options: PrintModeOptions) -> Result<i32>Expand description
Run in print (single-shot) mode.
Sends prompts to the agent and outputs the result. Returns an exit code.
pub async fn run_print_mode(app: &App, options: PrintModeOptions) -> Result<i32>Run in print (single-shot) mode.
Sends prompts to the agent and outputs the result. Returns an exit code.