pub struct RefreshedTokens {
pub access_token: String,
pub refresh_token: Option<String>,
pub expires_at: i64,
}Expand description
Tokens returned from a successful OAuth token-refresh grant.
expires_at is an absolute Unix epoch in seconds (now + expires_in).
refresh_token is preserved when the provider returns one in the
response and falls back to the input token when omitted (RFC 6749 6:
“the authorization server MAY issue a new refresh token, in which case
the client MUST replace the old refresh token”).
Fields
access_token: Stringrefresh_token: Option<String>expires_at: i64Trait Implementations
Sourceimpl Clone for RefreshedTokens
impl Clone for RefreshedTokens
Sourcefn clone(&self) -> RefreshedTokens
fn clone(&self) -> RefreshedTokens
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for RefreshedTokens
impl RefUnwindSafe for RefreshedTokens
impl Send for RefreshedTokens
impl Sync for RefreshedTokens
impl Unpin for RefreshedTokens
impl UnsafeUnpin for RefreshedTokens
impl UnwindSafe for RefreshedTokens