pub enum RpcCommand {
Show 29 variants
Prompt {
id: Option<String>,
message: String,
images: Option<Vec<ImageData>>,
streaming_behavior: Option<String>,
},
Steer {
id: Option<String>,
message: String,
images: Option<Vec<ImageData>>,
},
FollowUp {
id: Option<String>,
message: String,
images: Option<Vec<ImageData>>,
},
Abort {
id: Option<String>,
},
NewSession {
id: Option<String>,
parent_session: Option<String>,
},
GetState {
id: Option<String>,
},
SetModel {
id: Option<String>,
provider: String,
model_id: String,
},
CycleModel {
id: Option<String>,
},
GetAvailableModels {
id: Option<String>,
},
SetThinkingLevel {
id: Option<String>,
level: String,
},
CycleThinkingLevel {
id: Option<String>,
},
SetSteeringMode {
id: Option<String>,
mode: String,
},
SetFollowUpMode {
id: Option<String>,
mode: String,
},
Compact {
id: Option<String>,
custom_instructions: Option<String>,
},
SetAutoCompaction {
id: Option<String>,
enabled: bool,
},
SetAutoRetry {
id: Option<String>,
enabled: bool,
},
AbortRetry {
id: Option<String>,
},
Bash {
id: Option<String>,
command: String,
},
AbortBash {
id: Option<String>,
},
GetSessionStats {
id: Option<String>,
},
ExportHtml {
id: Option<String>,
output_path: Option<String>,
},
SwitchSession {
id: Option<String>,
session_path: String,
},
Fork {
id: Option<String>,
entry_id: String,
},
Clone {
id: Option<String>,
},
GetForkMessages {
id: Option<String>,
},
GetLastAssistantText {
id: Option<String>,
},
SetSessionName {
id: Option<String>,
name: String,
},
GetMessages {
id: Option<String>,
},
GetCommands {
id: Option<String>,
},
}Expand description
RPC command from client
Variants
Prompt
Send a prompt message to the agent.
Fields
Steer
Send a steering message to interrupt the current stream.
Fields
FollowUp
Send a follow-up message to be processed after the current stream.
Fields
Abort
Abort the current agent response.
NewSession
Create a new session.
Fields
GetState
Get the current agent state.
SetModel
Set the active model.
Fields
CycleModel
Cycle to the next available model.
GetAvailableModels
List all available models.
SetThinkingLevel
Set the thinking level.
Fields
CycleThinkingLevel
Cycle to the next thinking level.
SetSteeringMode
Set the steering mode.
Fields
SetFollowUpMode
Set the follow-up mode.
Fields
Compact
Manually trigger compaction.
Fields
SetAutoCompaction
Enable or disable auto-compaction.
Fields
SetAutoRetry
Enable or disable auto-retry.
Fields
AbortRetry
Abort the current retry attempt.
Bash
Execute a bash command.
Fields
AbortBash
Abort the running bash command.
GetSessionStats
Get session statistics.
ExportHtml
Export the session as HTML.
Fields
SwitchSession
Switch to a different session.
Fields
Fork
Fork the session at a given entry.
Fields
Clone
Clone the current session.
GetForkMessages
Get messages from the forked session.
GetLastAssistantText
Get the last assistant text response.
SetSessionName
Set the session display name.
Fields
GetMessages
Get all session messages.
GetCommands
get commands.