pub fn wrap_with_extractor(
inner: Arc<dyn MemoryBackend>,
settings: &Settings,
oxicode: Option<&Oxicode>,
) -> Arc<dyn MemoryBackend> ⓘExpand description
Wire the wrapper on top of an existing memory backend.
pub fn wrap_with_extractor(
inner: Arc<dyn MemoryBackend>,
settings: &Settings,
oxicode: Option<&Oxicode>,
) -> Arc<dyn MemoryBackend> ⓘWire the wrapper on top of an existing memory backend.