pub fn footer_hints(
view: DiffViewMode,
ws: WhitespaceMode,
wrap: bool,
) -> StringExpand description
Footer hint line. Returned as a String (not Line) so the test can assert content without bringing in ratatui’s Style.
pub fn footer_hints(
view: DiffViewMode,
ws: WhitespaceMode,
wrap: bool,
) -> StringFooter hint line. Returned as a String (not Line) so the test can assert content without bringing in ratatui’s Style.