emit_notification

Function emit_notification 

pub fn emit_notification(title: &str, message: &str)
Emit a desktop notification to stderr using the best detected protocol, wrapping for tmux passthrough when TMUX is set.