pub fn render_sequence(
protocol: NotificationProtocol,
title: &str,
message: &str,
) -> StringExpand description
Build the raw escape sequence for protocol carrying title/message.
pub fn render_sequence(
protocol: NotificationProtocol,
title: &str,
message: &str,
) -> StringBuild the raw escape sequence for protocol carrying title/message.