pub trait Encoder: Sealed {
type W: Writer;
type C: Config;
// Required methods
fn writer(&mut self) -> &mut Self::W;
fn config(&self) -> &Self::C;
}Expand description
Encoder trait for encoding values with configuration
This trait is the main interface for encoding values. It provides access to both the writer and the configuration.