pub fn fixture_root() -> Option<PathBuf>Expand description
Resolve the fixture root by walking the current CARGO_MANIFEST_DIR
upward. Returns None when the layout can’t be found (e.g. when
the crate is consumed as a dependency without the fixtures
directory).